@@ -6,7 +6,9 @@
 
 use alloc::vec::Vec;
 
+#[cfg(feature = "persistence")]
 use arbitrary::Arbitrary;
+
 use canonical::{Canon, CanonError, EncodeToVec, Id, Source};
 use canonical_derive::Canon;
 
@@ -18,16 +20,20 @@ const TAG_LEAF: u8 = 1;
 const TAG_LINK: u8 = 2;
 
 /// A generic annotation
-#[derive(Clone, Canon, Debug, PartialEq, Arbitrary)]
+#[derive(Clone, Canon, Debug, PartialEq)]
+#[cfg_attr(feature = "persistence", derive(Arbitrary))]
 pub struct GenericAnnotation(Vec<u8>);
 
 /// A generic leaf
-#[derive(Clone, Canon, Debug, PartialEq, Arbitrary)]
+#[derive(Clone, Canon, Debug, PartialEq)]
+#[cfg_attr(feature = "persistence", derive(Arbitrary))]
 pub struct GenericLeaf(Vec<u8>);
 
 impl GenericLeaf {
     pub(crate) fn new<C: Canon>(c: &C) -> Self {
-        GenericLeaf(c.encode_to_vec())
+        let vec = c.encode_to_vec();
+        let res = GenericLeaf(vec);
+        res
     }
 
     /// Cast the generic leaf to a concrete type
@@ -48,7 +54,8 @@ impl GenericAnnotation {
 }
 
 /// A generic child of a collection
-#[derive(Clone, Debug, PartialEq, Arbitrary)]
+#[derive(Clone, Debug, PartialEq)]
+#[cfg_attr(feature = "persistence", derive(Arbitrary))]
 pub enum GenericChild {
     /// Child is empty
     Empty,
@@ -104,7 +111,8 @@ impl Canon for GenericChild {
 /// prefixed lengths, so that the tree structure can still be followed even if
 /// you don't know the concrete associated and generic types of the Compound
 /// structure that was persisted
-#[derive(Default, Clone, Canon, Debug, PartialEq, Arbitrary)]
+#[derive(Default, Clone, Canon, Debug, PartialEq)]
+#[cfg_attr(feature = "persistence", derive(Arbitrary))]
 pub struct GenericTree(Vec<GenericChild>);
 
 impl GenericTree {
@@ -117,7 +125,9 @@ impl GenericTree {
     }
 
     pub(crate) fn push_leaf<L: Canon>(&mut self, leaf: &L) {
-        self.0.push(GenericChild::Leaf(GenericLeaf::new(leaf)))
+        let leaf = GenericLeaf::new(leaf);
+        let child = GenericChild::Leaf(leaf);
+        self.0.push(child)
     }
 
     pub(crate) fn push_link<C, A>(&mut self, link: &Link<C, A>)
